@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@codefactory.se>
+ * Author: Mikael Hallendal <micke@imendio.com>
  */
 
 #ifndef __YELP_HTML_H__
@@ -64,14 +64,18 @@ void            yelp_html_clear          (YelpHtml    *html);
 void            yelp_html_write          (YelpHtml    *html,
 					  const gchar *data,
 					  gint         len);
-void            yelp_html_printf         (YelpHtml *html, 
+void            yelp_html_printf         (YelpHtml    *html, 
 					  char        *format, 
 					  ...);
 void            yelp_html_close          (YelpHtml    *html);
 
-GtkWidget *     yelp_html_get_widget     (YelpHtml      *html);
+GtkWidget *     yelp_html_get_widget     (YelpHtml    *html);
 
-void            yelp_html_find_next      (YelpHtml *html);
+void            yelp_html_find           (YelpHtml    *html,
+					  const gchar *str,
+					  gboolean     match_case,
+					  gboolean     wrap,
+					  gboolean     forward);
 
 #endif /* __YELP_HTML_H__ */
 
