@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,13 +17,13 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@codefactory.se>
+ * Author: Mikael Hallendal <micke@imendio.com>
  */
 
 #ifndef __YELP_WINDOW_H__
 #define __YELP_WINDOW_H__
 
-#include <gtk/gtkwindow.h>
+#include <libgnomeui/gnome-app.h>
 #include <gtk/gtktreemodel.h>
 
 #include "yelp-base.h"
@@ -41,14 +41,14 @@ typedef struct _YelpWindowPriv   YelpWindowPriv;
 
 struct _YelpWindow
 {
-        GtkWindow       parent;
+        GnomeApp        parent;
         
         YelpWindowPriv *priv;
 };
 
 struct _YelpWindowClass
 {
-        GtkWindowClass  parent_class;
+        GnomeAppClass   parent_class;
 
         /* Signals */
 	void (*new_window_requested) (YelpWindow *window);
